@@ -2,12 +2,63 @@
 load_hbond_ts <- function( path,
                            mdEngine = "GROMOS" )
 {
-  timeseries <- read.table( path )
-  return( timeseries )
+  mdEngine <- toupper( mdEngine )
+  if( mdEngine != "GROMOS" &&
+      mdEngine != "GROMACS" &&
+      mdEngine != "AMBER" )
+    stop( paste( "The specified 'mdEngine', set to ", mdEngine, " is unknown.", sep = "" ) )
+  if( mdEngine == "GROMOS" )
+  {
+    timeseries <- read.table( path )
+    return( timeseries )
+  }
+  if( mdEngine == "GROMACS" )
+  {
+    DATA_input <- load_XPM( path )
+    
+    # because of the XPM definition, a reversing is necessary here
+    DATA_input$data <- apply( DATA_input$data, 2, rev )
+
+    VEC_times <- c()
+    VEC_which <- c()
+    for( i in 1:DATA_input[[ "numberRows" ]] )
+      for( j in 1:DATA_input[[ "numberColumns" ]] )
+      {
+        if( DATA_input[[ "data" ]][ i, j ] == "o" )
+        {
+          VEC_times <- c( VEC_times,
+                          j - 1 )
+          VEC_which <- c( VEC_which,
+                          i )
+        }
+      }
+    return( matrix( c( VEC_times,
+                       VEC_which ),
+                    byrow = FALSE,
+                    ncol = 2 ) )
+  }
+  if( mdEngine == "AMBER" )
+  {
+    inputData <- read.table( path )
+    VEC_times <- c()
+    VEC_which <- c()
+    for( i in 1:nrow( inputData ) )
+      for( j in 1:ncol( inputData ) )
+        if( inputData[ i, j ] == 1 )
+        {
+          VEC_times <- c( VEC_times,
+                          i )
+          VEC_which <- c( VEC_which,
+                          j - 1 )
+        }
+    return( matrix( c( VEC_times,
+                       VEC_which ),
+                    byrow = FALSE,
+                    ncol = 2 ) )
+  }
 }
 
 # plot hbond timeseries
-# WARNING: "timeRange" does not work
 hbond_ts <- function( timeseries,
                       summary,
                       acceptorRange = NA,
@@ -32,6 +83,9 @@ hbond_ts <- function( timeseries,
     donorRange <- c( min( summary[ , 2 ] ), max( summary[ , 2 ] ) )
   if( all( is.na( hbondIndices ) ) )
     hbondIndices <- list( c( min( summary[ , 1 ] ), max( summary[ , 1 ] ) ) )
+  else
+    if( is.list( hbondIndices ) == FALSE )
+      stop( "Error in input parsing: 'hbondIndices' needs to be a list of vectors of dimensionality 2." )
   #########
 
   # select the hbond-IDs of those hbonds, that match all criteria
@@ -46,6 +100,7 @@ hbond_ts <- function( timeseries,
       BOOL_add <- FALSE
       for( j in 1:length( hbondIndices ) )
       {
+        
         VEC_hbondIndCur <- hbondIndices[[ j ]]
         if( summary[ i, 1 ] >= VEC_hbondIndCur[ 1 ] &&
             summary[ i, 1 ] <= VEC_hbondIndCur[ 2 ] )
@@ -67,14 +122,11 @@ hbond_ts <- function( timeseries,
                             drop = FALSE ]
   #########
 
-  # set time axis
+  # set time limits
   VEC_timeLimits <- c( min( timeseries[ , 1 ] ),
                        max( timeseries[ , 1 ] ) )
   if( !all( is.na( timeRange ) ) )
     VEC_timeLimits <- timeRange
-  VEC_timeTicks <- VEC_timeLimits
-  if( !is.na( timeUnit ) )
-    VEC_timeTicks <- VEC_timeTicks / snapshotsPerTimeInt
   #########
 
   # get the vector for the names (left plot)
@@ -150,11 +202,12 @@ hbond_ts <- function( timeseries,
   #########
   
   # plot (left graph)
-  plot( timeseries,
-        xlim = VEC_timeLimits, xaxs = "i", xaxt = "n", xlab = "",
-        ylim = c( min( VEC_hbondIDs ), max( VEC_hbondIDs ) ), yaxt = "n", ylab = "",
-        type = "n" )
+  thePlot <- plot( timeseries,
+                   xlim = VEC_timeLimits, xaxs = "i", xaxt = "n", xlab = "",
+                   ylim = c( min( VEC_hbondIDs ), max( VEC_hbondIDs ) ), yaxt = "n", ylab = "",
+                   type = "n" )
   LIST_ellipsis <- list( ... )
+
   if( !barePlot )
   {
     mtext( side = 3, line = 1.25, cex = 1.45,
@@ -177,15 +230,14 @@ hbond_ts <- function( timeseries,
     mtext( side = 2, line = 2.45, cex = 1, text = "hbonds [#]" )
   if( !barePlot )
   {
+    VEC_timeTicks <- axTicks( 1,
+                              usr = VEC_timeLimits )[ 1:4 ]
+    VEC_timeLabels <- VEC_timeTicks
+    if( !is.na( timeUnit ) )
+      VEC_timeLabels <- VEC_timeTicks / snapshotsPerTimeInt
     axis( 1,
-          at = split_equidistant( VEC_values = VEC_timeLimits,
-                                  n = 6,
-                                  BOOL_removeLast = TRUE,
-                                  BOOL_roundDown = TRUE ),
-          labels = split_equidistant( VEC_values = VEC_timeTicks,
-                                      n = 6,
-                                      BOOL_removeLast = TRUE,
-                                      BOOL_roundDown = TRUE ) )
+          at = VEC_timeTicks,
+          labels = VEC_timeLabels )
     axis( 2,
           at = VEC_hbondNamesPositions,
           labels = VEC_hbondNames,
@@ -205,15 +257,17 @@ hbond_ts <- function( timeseries,
 
   # in case the occurences are to be plotted, add them on the right hand side
   VEC_occurences <- c()
+  VEC_instances <- timeseries[ ( timeseries[ , 1 ] >= VEC_timeLimits[ 1 ] ), , drop = FALSE]
+  VEC_instances <- VEC_instances[ ( VEC_instances[ , 1 ] <= VEC_timeLimits[ 2 ] ), , drop = FALSE ]
+
   for( i in 1:length( VEC_hbondIDs ) )
   {
-    INT_numberAppearances <- sum( timeseries[ , 2 ] == VEC_hbondIDs[ i ] )
+    INT_numberAppearances <- sum( VEC_instances[ , 2 ] == VEC_hbondIDs[ i ] )
     
     # calculate percent from the time limits
     # CAUTION: might differ from the overall score out of the summary file
     VEC_occurences <- c( VEC_occurences, ( INT_numberAppearances / 
-                                             ( VEC_timeLimits[ 2 ] - VEC_timeLimits[ 1 ] ) * 
-                                             100 ) )
+                                           ( VEC_timeLimits[ 2 ] - VEC_timeLimits[ 1 ] ) * 100 ) )
   }
   if( plotOccurences )
   {
@@ -250,47 +304,198 @@ hbond_ts <- function( timeseries,
 
 # load and parse GROMOS hbond output
 load_hbond <- function( path,
+                        GROMACShbondlogfile = NA,
                         mdEngine = "GROMOS" )
 {
-  CON_input <- file( path, open = "r" )
-  
-  #skip first comments
-  readLines( CON_input, n = 23, warn = FALSE )
-  LIST_buffer <- list()
-  INT_line <- 1
-  #########
-  
-  # read line by line and split by one or multiple spaces
-  # second block (three-centered hbonds) is skipped
-  while( length( STRING_theLine <- readLines( CON_input, n = 1, warn = FALSE ) ) > 0 )
+  VEC_outputColumnNames <- c( "hbondID", "resDonor", "resDonorName",
+                              "resAcceptor", "resAcceptorName", "atomDonor",
+                              "atomDonorName", "atomH", "atomAcceptor",
+                              "atomAcceptorName", "percentage" )
+  mdEngine <- toupper( mdEngine )
+  if( mdEngine != "GROMOS" &&
+      mdEngine != "GROMACS" &&
+      mdEngine != "AMBER" )
+    stop( paste( "The specified 'mdEngine', set to ", mdEngine, " is unknown.", sep = "" ) )
+  if( mdEngine == "GROMOS" )
   {
-    VEC_buffer <- unlist( strsplit( STRING_theLine, split = " +" ) )
-    if( length( VEC_buffer ) == 0 )
-      break
-    LIST_buffer[[ INT_line ]] <- VEC_buffer
-    INT_line <- INT_line + 1
+    CON_input <- file( path, open = "r" )
+  
+    # skip first comments
+    readLines( CON_input, n = 23, warn = FALSE )
+    LIST_buffer <- list()
+    INT_line <- 1
+    #########
+  
+    # read line by line and split by one or multiple spaces
+    # second block (three-centered hbonds) is skipped
+    while( length( STRING_theLine <- readLines( CON_input, n = 1, warn = FALSE ) ) > 0 )
+    {
+      VEC_buffer <- unlist( strsplit( STRING_theLine, split = " +" ) )
+      if( length( VEC_buffer ) == 0 )
+        break
+      LIST_buffer[[ INT_line ]] <- VEC_buffer
+      INT_line <- INT_line + 1
+    }
+    close( CON_input )
+    #########
+  
+    # transform list of lists into table using temporary file reads / writes and select
+    # the important columns only
+    DF_buffer <- data.frame( matrix( unlist( LIST_buffer ), ncol = 21, byrow = TRUE ),
+                             stringsAsFactors = FALSE )
+    input <- DF_buffer[ , c( -20, -19, -18, -15, -14, -12, -7, -6, -3, -1 ) ]
+    STRING_tempFile <- tempfile( "MDplot_Hbonds" )
+    on.exit( unlink( STRING_tempFile, recursive = FALSE, force = FALSE ) )
+    write.table( input, file = STRING_tempFile )
+    input <- read.table( STRING_tempFile )
+    #########
+  
+    # update column names
+    colnames( input ) <- VEC_outputColumnNames
+
+    #########
+    return( input )
   }
-  close( CON_input )
-  #########
   
-  # transform list of lists into table using temporary file reads / writes and select
-  # the important columns only
-  DF_buffer <- data.frame( matrix( unlist( LIST_buffer ), ncol = 21, byrow = TRUE ),
-                           stringsAsFactors = FALSE )
-  input <- DF_buffer[ , c( -20, -19, -18, -15, -14, -12, -7, -6, -3, -1 ) ]
-  STRING_tempFile <- tempfile( "MDplot_Hbonds" )
-  on.exit( unlink( STRING_tempFile, recursive = FALSE, force = FALSE ) )
-  write.table( input, file = STRING_tempFile )
-  input <- read.table( STRING_tempFile )
-  #########
+  if( mdEngine == "GROMACS" )
+  {
+    if( is.na( GROMACShbondlogfile ) )
+      stop( "When loading GROMACS hydrogen bond input, a second file (the logfile) has to be provided as agrument 'GROMACShbondlogfile'!" )
+    DATA_inputTimeseries <- load_XPM( path )
+
+    # because of the XPM definition, a reversing is necessary here
+    DATA_inputTimeseries$data <- apply( DATA_inputTimeseries$data, 2, rev )
+    
+    DATA_inputNames <- read.table( GROMACShbondlogfile )
+    LIST_donors <- list( split_GROMACS_atomnames( as.character( DATA_inputNames[[ 1 ]][ 1 ] ) ) )
+    LIST_hydrogens <- list( split_GROMACS_atomnames( as.character( DATA_inputNames[[ 2 ]][ 1 ] ) ) )
+    LIST_acceptors <- list( split_GROMACS_atomnames( as.character( DATA_inputNames[[ 3 ]][ 1 ] ) ) )
+    for( i in 2:length( DATA_inputNames[[ 1 ]] ) )
+    {
+      LIST_donors[[ length( LIST_donors ) + 1 ]] <- split_GROMACS_atomnames( as.character( DATA_inputNames[[ 1 ]][ i ] ) )
+      LIST_hydrogens[[ length( LIST_hydrogens ) + 1 ]] <- split_GROMACS_atomnames( as.character( DATA_inputNames[[ 2 ]][ i ] ) )
+      LIST_acceptors[[ length( LIST_acceptors ) + 1 ]] <- split_GROMACS_atomnames( as.character( DATA_inputNames[[ 3 ]][ i ] ) )
+    }
+    MAT_result <- matrix( c( 1:DATA_inputTimeseries[[ "numberRows" ]],
+                             rep( "", times = 10 * DATA_inputTimeseries[[ "numberRows" ]] ) ),
+                          ncol = 11,
+                          byrow = FALSE )
+    for( i in 1:DATA_inputTimeseries[[ "numberRows" ]] )
+    {
+      # insert donor information
+      MAT_result[ i, 2 ] <- LIST_donors[[ i ]][[ "residueNumber" ]]
+      MAT_result[ i, 3 ] <- LIST_donors[[ i ]][[ "residueName" ]]
+      MAT_result[ i, 7 ] <- LIST_donors[[ i ]][[ "atomName" ]]
+      
+      # insert acceptor information
+      MAT_result[ i, 4 ] <- LIST_acceptors[[ i ]][[ "residueNumber" ]]
+      MAT_result[ i, 5 ] <- LIST_acceptors[[ i ]][[ "residueName" ]]
+      MAT_result[ i, 10 ] <- LIST_acceptors[[ i ]][[ "atomName" ]]
+      
+      # calculate and insert percentage
+      REAL_percentage <- round( length( which( DATA_inputTimeseries[[ "data" ]][ i, ] == "o" ) ) /
+                                DATA_inputTimeseries[[ "numberColumns" ]] * 100, digits = 2 )
+      MAT_result[ i, 11 ] <- REAL_percentage
+    }
+    
+    # write and load temporary file for update
+    STRING_tempFile <- tempfile( "MDplot_Hbonds" )
+    on.exit( unlink( STRING_tempFile, recursive = FALSE, force = FALSE ) )
+    write.table( MAT_result, file = STRING_tempFile )
+    TABLE_result <- read.table( STRING_tempFile )
+    
+    # update column names
+    colnames( TABLE_result ) <- VEC_outputColumnNames
+    
+    return( TABLE_result )
+  }
   
-  # update column names
-  colnames( input ) <- c( "hbondID", "resDonor", "resDonorName",
-                          "resAcceptor", "resAcceptorName", "atomDonor",
-                          "atomDonorName", "atomH", "atomAcceptor",
-                          "atomAcceptorName", "percentage" )
-  #########
-  return( input )
+  # WARNING: function 'load_hbond()' does not support H-bonds formed with solvent yet
+  if( mdEngine == "AMBER" )
+  {
+    firstElement <- read.table( path )[ 1, 1 ]
+    CON_input <- file( path, open = "r" )
+    LIST_buffer <- list()
+    INT_line <- 1
+    TABLE_result <- NA
+    MAT_result <- NA
+
+    if( is.numeric( firstElement ) )
+    {
+      # -> input is timeseries file
+      
+      inputData <- read.table( path )[ , -1 ]
+      firstLine <- readLines( CON_input, n = 1, warn = FALSE )
+      close( CON_input )
+      VEC_names <- unlist( strsplit( firstLine, split = " +" ) )[ -1 ]
+      VEC_fractions <- round( apply( inputData,
+                                     2,
+                                     FUN = sum ) / nrow( inputData ) * 100,
+                              digits = 2 )
+      MAT_result <- matrix( c( 1:ncol( inputData ),
+                               rep( NA, times = 10 * ncol( inputData ) ) ),
+                            ncol = 11,
+                            byrow = FALSE )
+      for( i in 1:length( VEC_names ) )
+      {
+        VEC_currentNamesFragments <- unlist( strsplit( VEC_names[ i ],
+                                                       split = "-" ) )
+        LIST_acceptor = split_AMBER_atomnames( VEC_currentNamesFragments[ 1 ] )
+        LIST_donor = split_AMBER_atomnames( VEC_currentNamesFragments[ 2 ] )
+        MAT_result[ i, 2 ] <- LIST_donor$resNumber
+        MAT_result[ i, 3 ] <- LIST_donor$resName
+        MAT_result[ i, 4 ] <- LIST_acceptor$resNumber
+        MAT_result[ i, 5 ] <- LIST_acceptor$resName
+        MAT_result[ i, 7 ] <- LIST_donor$atomName
+        MAT_result[ i, 10 ] <- LIST_acceptor$atomName
+        MAT_result[ i, 11 ] <- VEC_fractions[ i ]
+      }
+    }
+    else
+    {
+      # -> input is summary file
+
+      while( length( STRING_theLine <- readLines( CON_input, n = 1, warn = FALSE ) ) > 0 )
+      {
+        if( !( grepl( "#", STRING_theLine ) ||
+               grepl( "Bridge ", STRING_theLine ) ||
+               grepl( "SolventAcc", STRING_theLine ) ) )
+        {
+          VEC_buffer <- unlist( strsplit( STRING_theLine, split = " +" ) )
+          LIST_buffer[[ INT_line ]] <- VEC_buffer
+          INT_line <- INT_line + 1
+        }
+      }
+      close( CON_input )
+
+      DF_buffer <- data.frame( matrix( unlist( LIST_buffer ), ncol = 7, byrow = TRUE ),
+                               stringsAsFactors = FALSE )
+      MAT_result <- matrix( c( 1:nrow( DF_buffer ),
+                               rep( NA, times = 10 * nrow( DF_buffer ) ) ),
+                            ncol = 11,
+                            byrow = FALSE )
+      for( i in 1:nrow( DF_buffer ) )
+      {
+        LIST_acceptor = split_AMBER_atomnames( DF_buffer[ i, 1 ] )
+        LIST_donor = split_AMBER_atomnames( DF_buffer[ i, 3 ] )
+        MAT_result[ i, 2 ] <- LIST_donor$resNumber
+        MAT_result[ i, 3 ] <- LIST_donor$resName
+        MAT_result[ i, 4 ] <- LIST_acceptor$resNumber
+        MAT_result[ i, 5 ] <- LIST_acceptor$resName
+        MAT_result[ i, 7 ] <- LIST_donor$atomName
+        MAT_result[ i, 10 ] <- LIST_acceptor$atomName
+        REAL_percentage <- round( as.numeric( DF_buffer[ i, 5 ] ) * 100,
+                                  digits = 2 )
+        MAT_result[ i, 11 ] <- REAL_percentage
+      }
+    }
+    STRING_tempFile <- tempfile( "MDplot_Hbonds" )
+    on.exit( unlink( STRING_tempFile, recursive = FALSE, force = FALSE ) )
+    write.table( MAT_result, file = STRING_tempFile )
+    TABLE_result <- read.table( STRING_tempFile )
+    colnames( TABLE_result ) <- VEC_outputColumnNames
+    return( TABLE_result )
+  }
 }
 
 # plot the hbond information
@@ -299,6 +504,7 @@ hbond <- function( hbonds,
                    acceptorRange = NA,
                    donorRange = NA,
                    printLegend = TRUE,
+                   showMultipleInteractions = TRUE,
                    barePlot = FALSE,
                    ... )
 {
@@ -322,23 +528,24 @@ hbond <- function( hbonds,
           if( ( MAT_result[ j, 2 ] == hbonds[ i, 2 ] ) &&
               ( MAT_result[ j, 4 ] == hbonds[ i, 4 ] ) )
           {
-            MAT_result[ j, 9 ] <- MAT_result[ j, 9 ] + hbonds[ i, 9 ]
+            MAT_result[ j, 11 ] <- max( MAT_result[ j, 11 ], hbonds[ i, 11 ] )
+            MAT_result[ j, 12 ] <- MAT_result[ j, 12 ] + 1
             BOOL_found = TRUE
             break
           }
         }
       }
       if( !BOOL_found )
-      {
-        MAT_result <- rbind( MAT_result, hbonds[ i, ] )
-      }
+        MAT_result <- rbind( MAT_result, cbind( hbonds[ i, ],
+                                                1 ) )
     }
+    colnames( MAT_result ) <- c( colnames( hbonds ), "numberInteractions" )
     #########
-    
+
     # remove unused columns and define zoom area if specified
-    MAT_result <- MAT_result[ , c( -8, -7, -6, -5, -3, -1 ) ]
+    MAT_result <- MAT_result[ , c( -10, -9, -8, -7, -6, -5, -3, -1 ) ]
     MAT_result <- MAT_result[ order( MAT_result[ , 1 ], MAT_result[ , 2 ] ), ]
-    PALETTE_residuewise <- colorRampPalette( rev( brewer.pal( 11, 'Spectral' ) ) )
+
     if( all( !is.na( acceptorRange ) ) )
     {
       MAT_result <- MAT_result[ MAT_result[ , 2 ] >= acceptorRange[ 1 ], , drop = FALSE ]
@@ -351,38 +558,62 @@ hbond <- function( hbonds,
     }
     #########
     
-    # normalize values to 0 to 100% and plot graph and legend (in case)
-    VEC_normalized <- lapply( as.list( MAT_result[ , 3 ] ), function( x ) x / 100 )
     if( printLegend && !barePlot )
     {
       par( mar = c( 4.25, 4.25, 3.25, 0.25 ) )
       layout( matrix( 1:2, ncol = 2 ), widths = c( 2.5, 0.5 ), heights = c( 1.0, 1.0 ) )
     }
+
     PALETTE_colors <- colorRampPalette( brewer.pal( 11, 'Spectral' ) )
     PALETTE_colors_rev <- colorRampPalette( rev( brewer.pal( 11, 'Spectral' ) ) )
-    plot( MAT_result[ , 1:2 ],
-          col = PALETTE_colors_rev( 10 )[ as.numeric( cut( as.numeric( VEC_normalized ), breaks = 10 ) )  ],
-          pch = 19,
+
+    VEC_colorsDots <- PALETTE_colors_rev( 21 )[ as.numeric( cut( c( 0, as.numeric( MAT_result[ , 3 ] ), 100 ), breaks = 21 ) )  ]
+    VEC_colorsDots <- VEC_colorsDots[ 2:( length( VEC_colorsDots ) - 1 ) ]
+    
+    v <- plot( MAT_result[ , 1:2 ],
+               col = VEC_colorsDots,
+               pch = 19,
           cex = 0.75,
           xlab = ifelse( barePlot, "", "Donor [residue number]" ),
           ylab = ifelse( barePlot, "", "Acceptor [residue number]" ),
           xaxt = ifelse( barePlot, "n", "s" ),
           yaxt = ifelse( barePlot, "n", "s" ),
+          xlim = c( min( MAT_result[ , 1 ] ) - 1,
+                    max( MAT_result[ , 1 ] ) + 1 ),
+          ylim = c( min( MAT_result[ , 2 ] ) - 1,
+                    max( MAT_result[ , 2 ] ) + 1 ),
           ... )
+    if( showMultipleInteractions )
+    {
+      par( new = TRUE )
+      plot( MAT_result[ MAT_result[ , 4 ] > 1, 1:2 ],
+            pch = 1,
+            col = "black",
+            cex = 0.75,
+            xaxt = "n",
+            yaxt = "n",
+            xlab = "",
+            ylab = "",
+            xlim = c( min( MAT_result[ , 1 ] ) - 1,
+                      max( MAT_result[ , 1 ] ) + 1 ),
+            ylim = c( min( MAT_result[ , 2 ] ) - 1,
+                      max( MAT_result[ , 2 ] ) + 1 ) )
+    }
     if( printLegend && !barePlot )
     {
       par( mar = c( 4.25, 0.25, 3.25, 1.0 ) )
-      legend_image <- as.raster( matrix( PALETTE_colors( 10 ), ncol = 1 ) )
+      legend_image <- as.raster( matrix( PALETTE_colors( 21 ), ncol = 1 ) )
       plot( c( 0, 2 ), c( 0, 1 ), type = 'n', axes = F, xlab = '', ylab = '', main = '[%]' )
       text( x = 1.5, y = seq( 0, 1, l = 5 ),
             labels = seq( 0, 100, l = 5 ) )
       rasterImage( legend_image, 0, 0, 1, 1 )
     }
     #########
+    
+    return( MAT_result )
   }
   else
   {
     stop( paste( "Error: plot method ", plotMethod, " is unknown. Process aborted!" ) )
   }
-  return( hbonds )
 }
\ No newline at end of file
